@@ -3,7 +3,10 @@ import numba
 
 from sklearn.base import BaseEstimator, TransformerMixin
 from sklearn.utils import check_array, check_random_state
-from sklearn.utils.validation import _check_sample_weight
+try:
+    from sklearn.utils.validation import _check_sample_weight
+except ImportError:
+    from enstop.utils import _check_sample_weight
 from scipy.sparse import issparse, csr_matrix, coo_matrix
 
 from enstop.utils import normalize, coherence, mean_coherence, log_lift, mean_log_lift
@@ -461,7 +464,7 @@ def plsa_fit_inner_blockwise(
     p_w_given_z,
     p_z_given_d,
     sample_weight,
-    block_size=16384,
+    block_size=65536,
     n_iter=100,
     n_iter_per_test=10,
     tolerance=0.001,
@@ -500,7 +503,7 @@ def plsa_fit_inner_blockwise(
     sample_weight: array of shape (n_docs,)
         Input document weights.
 
-    block_size: int (optional, default=16384)
+    block_size: int (optional, default=65536)
         The number of nonzero entries of X to process in a block. The larger this
         value the faster the compute may go, but at higher memory cost.
 
@@ -591,7 +594,7 @@ def plsa_fit(
     k,
     sample_weight,
     init="random",
-    block_size=16384,
+    block_size=65536,
     n_iter=100,
     n_iter_per_test=10,
     tolerance=0.001,
@@ -623,7 +626,7 @@ def plsa_fit(
             * ``"nmf"``
         or a tuple of two ndarrays of shape (n_docs, n_topics) and (n_topics, n_words).
 
-    block_size: int (optional, default=16384)
+    block_size: int (optional, default=65536)
         The number of nonzero entries of X to process in a block. The larger this
         value the faster the compute may go, but at higher memory cost.
 
@@ -842,7 +845,7 @@ def plsa_refit_inner_blockwise(
     topics,
     p_z_given_d,
     sample_weight,
-    block_size=16384,
+    block_size=65536,
     n_iter=50,
     n_iter_per_test=10,
     tolerance=0.005,
@@ -879,7 +882,7 @@ def plsa_refit_inner_blockwise(
     sample_weight: array of shape (n_docs,)
         Input document weights.
 
-    block_size: int (optional, default=16384)
+    block_size: int (optional, default=65536)
         The number of nonzero entries of X to process in a block. The larger this
         value the faster the compute may go, but at higher memory cost.
 
@@ -946,7 +949,7 @@ def plsa_refit(
     X,
     topics,
     sample_weight,
-    block_size=16384,
+    block_size=65536,
     n_iter=50,
     n_iter_per_test=10,
     tolerance=0.005,
@@ -968,7 +971,7 @@ def plsa_refit(
     sample_weight: array of shape (n_docs,)
         Input document weights.
 
-    block_size: int (optional, default=16384)
+    block_size: int (optional, default=65536)
         The number of nonzero entries of X to process in a block. The larger this
         value the faster the compute may go, but at higher memory cost.
 
@@ -1055,7 +1058,7 @@ class StreamedPLSA(BaseEstimator, TransformerMixin):
             * ``"nmf"``
         or a tuple of two ndarrays of shape (n_docs, n_topics) and (n_topics, n_words).
 
-    block_size: int (optional, default=16384)
+    block_size: int (optional, default=65536)
         The number of nonzero entries of X to process in a block. The larger this
         value the faster the compute may go, but at higher memory cost.
 
@@ -1111,7 +1114,7 @@ class StreamedPLSA(BaseEstimator, TransformerMixin):
         self,
         n_components=10,
         init="random",
-        block_size=16384,
+        block_size=65536,
         n_iter=100,
         n_iter_per_test=10,
         tolerance=0.001,
@@ -1200,13 +1203,13 @@ class StreamedPLSA(BaseEstimator, TransformerMixin):
             data_for_fitting,
             self.n_components,
             sample_weight,
-            self.init,
-            self.block_size,
-            self.n_iter,
-            self.n_iter_per_test,
-            self.tolerance,
-            self.e_step_thresh,
-            self.random_state,
+            init=self.init,
+            block_size=self.block_size,
+            n_iter=self.n_iter,
+            n_iter_per_test=self.n_iter_per_test,
+            tolerance=self.tolerance,
+            e_step_thresh=self.e_step_thresh,
+            random_state=self.random_state,
         )
 
         if zero_rows_found:
@@ -1220,7 +1223,7 @@ class StreamedPLSA(BaseEstimator, TransformerMixin):
 
         return U
 
-    def transform(self, X, y=None):
+    def transform(self, X, y=None, sample_weight=None):
         """Transform the data X into the topic space of the fitted pLSA model.
 
         Parameters
@@ -1236,6 +1239,8 @@ class StreamedPLSA(BaseEstimator, TransformerMixin):
             An embedding of the documents X into the topic space.
         """
         X = check_array(X, accept_sparse="csr")
+        sample_weight = _check_sample_weight(
+            sample_weight, X, dtype=np.float32)
         random_state = check_random_state(self.transform_random_seed)
 
         if not issparse(X):
@@ -1246,6 +1251,8 @@ class StreamedPLSA(BaseEstimator, TransformerMixin):
         result = plsa_refit(
             X,
             self.components_,
+            sample_weight,
+            block_size=self.block_size,
             n_iter=50,
             n_iter_per_test=5,
             tolerance=0.001,
